@@ -434,7 +434,12 @@ def _selectable_name(selectable):
 class SqlSoup:
     
     def class_for_table(self, selectable, **mapper_kwargs):
-        selectable = expression._selectable(selectable)
+        try:
+            get_selectable = expression._selectable
+        except AttributeError:
+            # SA 0.5.3
+            get_selectable = expression._clause_element_as_expr
+        selectable = get_selectable(selectable)
         mapname =  _selectable_name(selectable)
         if isinstance(selectable, Table):
             klass = TableClassType(mapname, (object,), {})
